      SUBROUTINE P1_1(A,E,L,N,S,O)
C     DETERMINATION OF THE EQUATORIAL CONSTANTS P, Q AND A, B FOR AN ELLIPTICAL ORBIT
C     FROM ORBITS FOR AMATEURS, VOLUME 1
      IMPLICIT NONE
      REAL*8 A,E,L,N,S,O
C     A = SEMIMAJOR AXIS
C     E = ECCENTRICITY
C     L = LONGITUDE OF PERIHELION
C     N = LONGITUDE OF THE ASCENDING NODE (CAPITAL OMEGA)
C     S = INCLINATION
C     O = OBLIQUITY
      END
